Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1304)

Unified Diff: pkg/args/lib/args.dart

Issue 14173003: Remove Collection, Collections and clean up List/Set/Queue implementations of retain/remove. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/args/lib/args.dart
diff --git a/pkg/args/lib/args.dart b/pkg/args/lib/args.dart
index 48cef1642ece730acba2bbc42027c05a910255b0..1337b46a6a8f40ac92b72a14c175eee7e8c867bb 100644
--- a/pkg/args/lib/args.dart
+++ b/pkg/args/lib/args.dart
@@ -417,7 +417,7 @@ class ArgResults {
return _options[name];
}
- /** Get the names of the options as a [Collection]. */
- Collection<String> get options => _options.keys.toList(growable: false);
+ /** Get the names of the options as an [Iterable]. */
+ Iterable<String> get options => _options.keys;
}

Powered by Google App Engine
This is Rietveld 408576698